Module beamlit.models.pending_invitation_accept
===============================================

Classes
-------

`PendingInvitationAccept(email: beamlit.types.Unset | str = <beamlit.types.Unset object>, workspace: beamlit.types.Unset | ForwardRef('Workspace') = <beamlit.types.Unset object>)`
:   Pending invitation accept
    
    Attributes:
        email (Union[Unset, str]): User email
        workspace (Union[Unset, Workspace]): Workspace
    
    Method generated by attrs for class PendingInvitationAccept.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `email`
    :

    `workspace`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :